const videoInput = document.querySelector('#video-input');
const submitButton = document.querySelector('#submit');
const videoOutput = document.querySelector('#video-output');
const errorDiv = document.querySelector('#error');
const spinner = document.getElementById('loader');

const API_ENDPOINT = 'http://localhost:3000/convert';

submitButton.addEventListener('click', async () => {
    errorDiv.innerText = '';
    const {files} = videoInput;
    if (files.length === 0 || !['video/mp4', 'video/x-matroska'].includes(files[0].type)) {
        console.log(files)
        error('No video selected, please select a video');
        return;
    }
    spinner.hidden = false;
    try {
        const convertedVideo = await uploadVideo(files[0]);
        videoOutput.src = URL.createObjectURL(convertedVideo);
    } catch (e) {
        error(e);
    }
    spinner.hidden = true;
})

function error(message) {
    errorDiv.innerText = 'ERROR : ' + message;
}

async function uploadVideo(video) {
    const formData = new FormData();
    formData.append('video', video);

    const res = await fetch(API_ENDPOINT, {
        method: 'POST',
        body: formData
    });

    if (!res.ok) {
        throw new Error('Upload failed : ' + res.statusText);
    }

    const videoArrayBuffer = await res.arrayBuffer();
    return new File([videoArrayBuffer], 'converted.mp4', {type: 'video/mp4'});
}